/*Replication materials for 
"Sticking It Out: Instability, Regime Type, and Personnel 
Withdrawals from UN Peacekeeping Operations."
Authors: Molly M. Melin & Jacob D. Kathman
*/


use "CMPS Replication_11-15-22.dta"

*M1: Base Model
nbreg total_contrib_change1moNeg demdum6_potencontrib brv_AllLag  total_contrib_change1moNegLag total_contribLag totaldeaths_missionmonLag contig_land numMS_deployed total_fullmiss_change1moLag deployment_dur* activedum shared_colonial_members colonial_intervener incompatibility if deployed == 1, robust 

*M2: Democracy Interaction Model
nbreg total_contrib_change1moNeg i.demdum6_potencontrib##c.brv_AllLag total_contrib_change1moNegLag total_contribLag totaldeaths_missionmonLag contig_land numMS_deployed total_fullmiss_change1moLag deployment_dur* activedum shared_colonial_members colonial_intervener incompatibility if deployed == 1, robust

*M3: Democracy Interaction Model, Active Conflicts
nbreg total_contrib_change1moNeg i.demdum6_potencontrib##c.brv_AllLag total_contrib_change1moNegLag total_contribLag totaldeaths_missionmonLag contig_land numMS_deployed total_fullmiss_change1moLag deployment_dur* shared_colonial_members colonial_intervener incompatibility if deployed == 1 & active_24months==1, robust 

*Figure 1: Below we estimate withdrawal sizes for each month of the Dutch deployment to Bosnia.
*Using Model 2, and holding all IVs constant, we vary only the regime type (demdum6_potencontrib) 
*to predict the size of a democratic withdrawal size (total_contrib_change1moNeg) as compared to 
*a nondemocratic withdrawal in the face of combat violence (brv_AllLag).
*The histogram values in Figure 1 are indicated in the values set for brv_AllLag in each labeled month.
*The line values aggregate over time, using the difference between the predicted value for the 'margins'
*command when demdum6_potencontrib is set at '1' (democracy) relative to when demdum6_potencontrib
*is set at '0' (nondemocracy). We report the difference in predicted values next to each month/year that
*precedes the 'margins' commands.
*M2
nbreg total_contrib_change1moNeg i.demdum6_potencontrib##c.brv_AllLag total_contrib_change1moNegLag total_contribLag totaldeaths_missionmonLag contig_land numMS_deployed total_fullmiss_change1moLag deployment_dur* activedum shared_colonial_members colonial_intervener incompatibility if deployed == 1, robust
**1993.09: Battle Deaths = 56; Democracy reduces withdrawal by ~.3
margins, at (demdum6_potencontrib=(1) brv_AllLag=(56) total_contrib_change1moNegLag=(26) total_contribLag=(1010) totaldeaths_missionmonLag=(0) contig_land=(0) numMS_deployed=(34) total_fullmiss_change1moLag=(78) deployment_dur=(15) deployment_durSq=(225) deployment_durCu=(3375) activedum=(1) shared_colonial_members=(0) colonial_intervener=(0) incompatibility=(1)) vsquish
margins, at (demdum6_potencontrib=(0) brv_AllLag=(56) total_contrib_change1moNegLag=(26) total_contribLag=(1010) totaldeaths_missionmonLag=(0) contig_land=(0) numMS_deployed=(34) total_fullmiss_change1moLag=(78) deployment_dur=(15) deployment_durSq=(225) deployment_durCu=(3375) activedum=(1) shared_colonial_members=(0) colonial_intervener=(0) incompatibility=(1)) vsquish
**1993.10: democracy reduces withdrawal by ~2
margins, at (demdum6_potencontrib=(1) brv_AllLag=(12) total_contrib_change1moNegLag=(0) total_contribLag=(1894) totaldeaths_missionmonLag=(0) contig_land=(0) numMS_deployed=(35) total_fullmiss_change1moLag=(790) deployment_dur=(16) deployment_durSq=(256) deployment_durCu=(4096) activedum=(1) shared_colonial_members=(0) colonial_intervener=(0) incompatibility=(1)) vsquish
margins, at (demdum6_potencontrib=(0) brv_AllLag=(12) total_contrib_change1moNegLag=(0) total_contribLag=(1894) totaldeaths_missionmonLag=(0) contig_land=(0) numMS_deployed=(35) total_fullmiss_change1moLag=(790) deployment_dur=(16) deployment_durSq=(256) deployment_durCu=(4096) activedum=(1) shared_colonial_members=(0) colonial_intervener=(0) incompatibility=(1)) vsquish
**1993.11: democracy reduces withdrawal by ~95
margins, at (demdum6_potencontrib=(1) brv_AllLag=(94) total_contrib_change1moNegLag=(811) total_contribLag=(1083) totaldeaths_missionmonLag=(1) contig_land=(0) numMS_deployed=(35) total_fullmiss_change1moLag=(1291) deployment_dur=(17) deployment_durSq=(289) deployment_durCu=(4913) activedum=(1) shared_colonial_members=(0) colonial_intervener=(0) incompatibility=(1)) vsquish
margins, at (demdum6_potencontrib=(0) brv_AllLag=(94) total_contrib_change1moNegLag=(811) total_contribLag=(1083) totaldeaths_missionmonLag=(1) contig_land=(0) numMS_deployed=(35) total_fullmiss_change1moLag=(1291) deployment_dur=(17) deployment_durSq=(289) deployment_durCu=(4913) activedum=(1) shared_colonial_members=(0) colonial_intervener=(0) incompatibility=(1)) vsquish
**1993.12: democracy reduces withdrawal by ~.5
margins, at (demdum6_potencontrib=(1) brv_AllLag=(72) total_contrib_change1moNegLag=(1) total_contribLag=(1082) totaldeaths_missionmonLag=(0) contig_land=(0) numMS_deployed=(34) total_fullmiss_change1moLag=(-593) deployment_dur=(18) deployment_durSq=(324) deployment_durCu=(5832) activedum=(1) shared_colonial_members=(0) colonial_intervener=(0) incompatibility=(1)) vsquish
margins, at (demdum6_potencontrib=(0) brv_AllLag=(72) total_contrib_change1moNegLag=(1) total_contribLag=(1082) totaldeaths_missionmonLag=(0) contig_land=(0) numMS_deployed=(34) total_fullmiss_change1moLag=(-593) deployment_dur=(18) deployment_durSq=(324) deployment_durCu=(5832) activedum=(1) shared_colonial_members=(0) colonial_intervener=(0) incompatibility=(1)) vsquish
**1994.01: democracy reduces withdrawal by ~.5
margins, at (demdum6_potencontrib=(1) brv_AllLag=(68) total_contrib_change1moNegLag=(10) total_contribLag=(1072) totaldeaths_missionmonLag=(1) contig_land=(0) numMS_deployed=(34) total_fullmiss_change1moLag=(637) deployment_dur=(19) deployment_durSq=(361) deployment_durCu=(6859) activedum=(1) shared_colonial_members=(0) colonial_intervener=(0) incompatibility=(1)) vsquish
margins, at (demdum6_potencontrib=(0) brv_AllLag=(68) total_contrib_change1moNegLag=(10) total_contribLag=(1072) totaldeaths_missionmonLag=(1) contig_land=(0) numMS_deployed=(34) total_fullmiss_change1moLag=(637) deployment_dur=(19) deployment_durSq=(361) deployment_durCu=(6859) activedum=(1) shared_colonial_members=(0) colonial_intervener=(0) incompatibility=(1)) vsquish
**1994.02: democracy reduces withdrawal by ~2.5
margins, at (demdum6_potencontrib=(1) brv_AllLag=(244) total_contrib_change1moNegLag=(0) total_contribLag=(1132) totaldeaths_missionmonLag=(1) contig_land=(0) numMS_deployed=(34) total_fullmiss_change1moLag=(1403) deployment_dur=(20) deployment_durSq=(400) deployment_durCu=(8000) activedum=(1) shared_colonial_members=(0) colonial_intervener=(0) incompatibility=(1)) vsquish
margins, at (demdum6_potencontrib=(0) brv_AllLag=(244) total_contrib_change1moNegLag=(0) total_contribLag=(1132) totaldeaths_missionmonLag=(1) contig_land=(0) numMS_deployed=(34) total_fullmiss_change1moLag=(1403) deployment_dur=(20) deployment_durSq=(400) deployment_durCu=(8000) activedum=(1) shared_colonial_members=(0) colonial_intervener=(0) incompatibility=(1)) vsquish
**1994.03: democracy reduces withdrawal by ~6
margins, at (demdum6_potencontrib=(1) brv_AllLag=(170) total_contrib_change1moNegLag=(0) total_contribLag=(1562) totaldeaths_missionmonLag=(0) contig_land=(0) numMS_deployed=(34) total_fullmiss_change1moLag=(2150) deployment_dur=(21) deployment_durSq=(441) deployment_durCu=(9261) activedum=(1) shared_colonial_members=(0) colonial_intervener=(0) incompatibility=(1)) vsquish
margins, at (demdum6_potencontrib=(0) brv_AllLag=(170) total_contrib_change1moNegLag=(0) total_contribLag=(1562) totaldeaths_missionmonLag=(0) contig_land=(0) numMS_deployed=(34) total_fullmiss_change1moLag=(2150) deployment_dur=(21) deployment_durSq=(441) deployment_durCu=(9261) activedum=(1) shared_colonial_members=(0) colonial_intervener=(0) incompatibility=(1)) vsquish
**1994.04: democracy reduces withdrawal by ~38
margins, at (demdum6_potencontrib=(1) brv_AllLag=(515) total_contrib_change1moNegLag=(0) total_contribLag=(1697) totaldeaths_missionmonLag=(0) contig_land=(0) numMS_deployed=(34) total_fullmiss_change1moLag=(1669) deployment_dur=(22) deployment_durSq=(484) deployment_durCu=(10648) activedum=(1) shared_colonial_members=(0) colonial_intervener=(0) incompatibility=(1)) vsquish
margins, at (demdum6_potencontrib=(0) brv_AllLag=(515) total_contrib_change1moNegLag=(0) total_contribLag=(1697) totaldeaths_missionmonLag=(0) contig_land=(0) numMS_deployed=(34) total_fullmiss_change1moLag=(1669) deployment_dur=(22) deployment_durSq=(484) deployment_durCu=(10648) activedum=(1) shared_colonial_members=(0) colonial_intervener=(0) incompatibility=(1)) vsquish
**1994.05: democracy reduces withdrawal by ~146
margins, at (demdum6_potencontrib=(1) brv_AllLag=(380) total_contrib_change1moNegLag=(0) total_contribLag=(2202) totaldeaths_missionmonLag=(0) contig_land=(0) numMS_deployed=(33) total_fullmiss_change1moLag=(2386) deployment_dur=(23) deployment_durSq=(529) deployment_durCu=(12167) activedum=(1) shared_colonial_members=(0) colonial_intervener=(0) incompatibility=(1)) vsquish
margins, at (demdum6_potencontrib=(0) brv_AllLag=(380) total_contrib_change1moNegLag=(0) total_contribLag=(2202) totaldeaths_missionmonLag=(0) contig_land=(0) numMS_deployed=(33) total_fullmiss_change1moLag=(2386) deployment_dur=(23) deployment_durSq=(529) deployment_durCu=(12167) activedum=(1) shared_colonial_members=(0) colonial_intervener=(0) incompatibility=(1)) vsquish
**1994.06: democracy reduces withdrawal by ~9
margins, at (demdum6_potencontrib=(1) brv_AllLag=(41) total_contrib_change1moNegLag=(0) total_contribLag=(2212) totaldeaths_missionmonLag=(0) contig_land=(0) numMS_deployed=(35) total_fullmiss_change1moLag=(385) deployment_dur=(24) deployment_durSq=(576) deployment_durCu=(13824) activedum=(1) shared_colonial_members=(0) colonial_intervener=(0) incompatibility=(1)) vsquish
margins, at (demdum6_potencontrib=(0) brv_AllLag=(41) total_contrib_change1moNegLag=(0) total_contribLag=(2212) totaldeaths_missionmonLag=(0) contig_land=(0) numMS_deployed=(35) total_fullmiss_change1moLag=(385) deployment_dur=(24) deployment_durSq=(576) deployment_durCu=(13824) activedum=(1) shared_colonial_members=(0) colonial_intervener=(0) incompatibility=(1)) vsquish
**1994.07: democracy reduces withdrawal by ~-.8
margins, at (demdum6_potencontrib=(1) brv_AllLag=(24) total_contrib_change1moNegLag=(209) total_contribLag=(2003) totaldeaths_missionmonLag=(0) contig_land=(0) numMS_deployed=(35) total_fullmiss_change1moLag=(1427) deployment_dur=(25) deployment_durSq=(625) deployment_durCu=(15625) activedum=(1) shared_colonial_members=(0) colonial_intervener=(0) incompatibility=(1)) vsquish
margins, at (demdum6_potencontrib=(0) brv_AllLag=(24) total_contrib_change1moNegLag=(209) total_contribLag=(2003) totaldeaths_missionmonLag=(0) contig_land=(0) numMS_deployed=(35) total_fullmiss_change1moLag=(1427) deployment_dur=(25) deployment_durSq=(625) deployment_durCu=(15625) activedum=(1) shared_colonial_members=(0) colonial_intervener=(0) incompatibility=(1)) vsquish
**1994.08: democracy reduces withdrawal by ~-5.7
margins, at (demdum6_potencontrib=(1) brv_AllLag=(10) total_contrib_change1moNegLag=(0) total_contribLag=(2147) totaldeaths_missionmonLag=(0) contig_land=(0) numMS_deployed=(35) total_fullmiss_change1moLag=(1366) deployment_dur=(26) deployment_durSq=(676) deployment_durCu=(17576) activedum=(1) shared_colonial_members=(0) colonial_intervener=(0) incompatibility=(1)) vsquish
margins, at (demdum6_potencontrib=(0) brv_AllLag=(10) total_contrib_change1moNegLag=(0) total_contribLag=(2147) totaldeaths_missionmonLag=(0) contig_land=(0) numMS_deployed=(35) total_fullmiss_change1moLag=(1366) deployment_dur=(26) deployment_durSq=(676) deployment_durCu=(17576) activedum=(1) shared_colonial_members=(0) colonial_intervener=(0) incompatibility=(1)) vsquish
**1994.09: democracy reduces withdrawal by ~-5.2
margins, at (demdum6_potencontrib=(1) brv_AllLag=(17) total_contrib_change1moNegLag=(185) total_contribLag=(1962) totaldeaths_missionmonLag=(0) contig_land=(0) numMS_deployed=(35) total_fullmiss_change1moLag=(982) deployment_dur=(27) deployment_durSq=(729) deployment_durCu=(19683) activedum=(1) shared_colonial_members=(0) colonial_intervener=(0) incompatibility=(1)) vsquish
margins, at (demdum6_potencontrib=(0) brv_AllLag=(17) total_contrib_change1moNegLag=(185) total_contribLag=(1962) totaldeaths_missionmonLag=(0) contig_land=(0) numMS_deployed=(35) total_fullmiss_change1moLag=(982) deployment_dur=(27) deployment_durSq=(729) deployment_durCu=(19683) activedum=(1) shared_colonial_members=(0) colonial_intervener=(0) incompatibility=(1)) vsquish
**1994.1: democracy reduces withdrawal by ~19.6
margins, at (demdum6_potencontrib=(1) brv_AllLag=(102) total_contrib_change1moNegLag=(85) total_contribLag=(1877) totaldeaths_missionmonLag=(0) contig_land=(0) numMS_deployed=(34) total_fullmiss_change1moLag=(1207) deployment_dur=(28) deployment_durSq=(784) deployment_durCu=(21952) activedum=(1) shared_colonial_members=(0) colonial_intervener=(0) incompatibility=(1)) vsquish
margins, at (demdum6_potencontrib=(0) brv_AllLag=(102) total_contrib_change1moNegLag=(85) total_contribLag=(1877) totaldeaths_missionmonLag=(0) contig_land=(0) numMS_deployed=(34) total_fullmiss_change1moLag=(1207) deployment_dur=(28) deployment_durSq=(784) deployment_durCu=(21952) activedum=(1) shared_colonial_members=(0) colonial_intervener=(0) incompatibility=(1)) vsquish
**1994.11: democracy reduces withdrawal by ~33.8
margins, at (demdum6_potencontrib=(1) brv_AllLag=(189) total_contrib_change1moNegLag=(0) total_contribLag=(1896) totaldeaths_missionmonLag=(0) contig_land=(0) numMS_deployed=(36) total_fullmiss_change1moLag=(-127) deployment_dur=(29) deployment_durSq=(841) deployment_durCu=(24389) activedum=(1) shared_colonial_members=(0) colonial_intervener=(0) incompatibility=(1)) vsquish
margins, at (demdum6_potencontrib=(0) brv_AllLag=(189) total_contrib_change1moNegLag=(0) total_contribLag=(1896) totaldeaths_missionmonLag=(0) contig_land=(0) numMS_deployed=(36) total_fullmiss_change1moLag=(-127) deployment_dur=(29) deployment_durSq=(841) deployment_durCu=(24389) activedum=(1) shared_colonial_members=(0) colonial_intervener=(0) incompatibility=(1)) vsquish
**1994.12: democracy reduces withdrawal by ~3.8
margins, at (demdum6_potencontrib=(1) brv_AllLag=(42) total_contrib_change1moNegLag=(35) total_contribLag=(1861) totaldeaths_missionmonLag=(0) contig_land=(0) numMS_deployed=(35) total_fullmiss_change1moLag=(-258) deployment_dur=(30) deployment_durSq=(900) deployment_durCu=(27000) activedum=(1) shared_colonial_members=(0) colonial_intervener=(0) incompatibility=(1)) vsquish
margins, at (demdum6_potencontrib=(0) brv_AllLag=(42) total_contrib_change1moNegLag=(35) total_contribLag=(1861) totaldeaths_missionmonLag=(0) contig_land=(0) numMS_deployed=(35) total_fullmiss_change1moLag=(-258) deployment_dur=(30) deployment_durSq=(900) deployment_durCu=(27000) activedum=(1) shared_colonial_members=(0) colonial_intervener=(0) incompatibility=(1)) vsquish
**1995.01: democracy reduces withdrawal by ~3.4
margins, at (demdum6_potencontrib=(1) brv_AllLag=(45) total_contrib_change1moNegLag=(4) total_contribLag=(1857) totaldeaths_missionmonLag=(0) contig_land=(0) numMS_deployed=(36) total_fullmiss_change1moLag=(252) deployment_dur=(31) deployment_durSq=(961) deployment_durCu=(29791) activedum=(1) shared_colonial_members=(0) colonial_intervener=(0) incompatibility=(1)) vsquish
margins, at (demdum6_potencontrib=(0) brv_AllLag=(45) total_contrib_change1moNegLag=(4) total_contribLag=(1857) totaldeaths_missionmonLag=(0) contig_land=(0) numMS_deployed=(36) total_fullmiss_change1moLag=(252) deployment_dur=(31) deployment_durSq=(961) deployment_durCu=(29791) activedum=(1) shared_colonial_members=(0) colonial_intervener=(0) incompatibility=(1)) vsquish
**1995.02: democracy reduces withdrawal by ~7.4
margins, at (demdum6_potencontrib=(1) brv_AllLag=(57) total_contrib_change1moNegLag=(106) total_contribLag=(1751) totaldeaths_missionmonLag=(0) contig_land=(0) numMS_deployed=(37) total_fullmiss_change1moLag=(-112) deployment_dur=(32) deployment_durSq=(1024) deployment_durCu=(32768) activedum=(1) shared_colonial_members=(0) colonial_intervener=(0) incompatibility=(1)) vsquish
margins, at (demdum6_potencontrib=(0) brv_AllLag=(57) total_contrib_change1moNegLag=(106) total_contribLag=(1751) totaldeaths_missionmonLag=(0) contig_land=(0) numMS_deployed=(37) total_fullmiss_change1moLag=(-112) deployment_dur=(32) deployment_durSq=(1024) deployment_durCu=(32768) activedum=(1) shared_colonial_members=(0) colonial_intervener=(0) incompatibility=(1)) vsquish
**1995.03: democracy reduces withdrawal by ~1.9
margins, at (demdum6_potencontrib=(1) brv_AllLag=(40) total_contrib_change1moNegLag=(33) total_contribLag=(1718) totaldeaths_missionmonLag=(0) contig_land=(0) numMS_deployed=(37) total_fullmiss_change1moLag=(89) deployment_dur=(33) deployment_durSq=(1089) deployment_durCu=(35937) activedum=(1) shared_colonial_members=(0) colonial_intervener=(0) incompatibility=(1)) vsquish
margins, at (demdum6_potencontrib=(0) brv_AllLag=(40) total_contrib_change1moNegLag=(33) total_contribLag=(1718) totaldeaths_missionmonLag=(0) contig_land=(0) numMS_deployed=(37) total_fullmiss_change1moLag=(89) deployment_dur=(33) deployment_durSq=(1089) deployment_durCu=(35937) activedum=(1) shared_colonial_members=(0) colonial_intervener=(0) incompatibility=(1)) vsquish
**1995.04: democracy reduces withdrawal by ~22.9
margins, at (demdum6_potencontrib=(1) brv_AllLag=(173) total_contrib_change1moNegLag=(0) total_contribLag=(1731) totaldeaths_missionmonLag=(1) contig_land=(0) numMS_deployed=(33) total_fullmiss_change1moLag=(-918) deployment_dur=(34) deployment_durSq=(1156) deployment_durCu=(39304) activedum=(1) shared_colonial_members=(0) colonial_intervener=(0) incompatibility=(1)) vsquish
margins, at (demdum6_potencontrib=(0) brv_AllLag=(173) total_contrib_change1moNegLag=(0) total_contribLag=(1731) totaldeaths_missionmonLag=(1) contig_land=(0) numMS_deployed=(33) total_fullmiss_change1moLag=(-918) deployment_dur=(34) deployment_durSq=(1156) deployment_durCu=(39304) activedum=(1) shared_colonial_members=(0) colonial_intervener=(0) incompatibility=(1)) vsquish
**1995.05: democracy reduces withdrawal by ~66.6
margins, at (demdum6_potencontrib=(1) brv_AllLag=(62) total_contrib_change1moNegLag=(139) total_contribLag=(1592) totaldeaths_missionmonLag=(0) contig_land=(0) numMS_deployed=(30) total_fullmiss_change1moLag=(-15249) deployment_dur=(35) deployment_durSq=(1225) deployment_durCu=(42875) activedum=(1) shared_colonial_members=(0) colonial_intervener=(0) incompatibility=(1)) vsquish
margins, at (demdum6_potencontrib=(0) brv_AllLag=(62) total_contrib_change1moNegLag=(139) total_contribLag=(1592) totaldeaths_missionmonLag=(0) contig_land=(0) numMS_deployed=(30) total_fullmiss_change1moLag=(-15249) deployment_dur=(35) deployment_durSq=(1225) deployment_durCu=(42875) activedum=(1) shared_colonial_members=(0) colonial_intervener=(0) incompatibility=(1)) vsquish
**1995.06: democracy reduces withdrawal by ~21.6
margins, at (demdum6_potencontrib=(1) brv_AllLag=(298) total_contrib_change1moNegLag=(13) total_contribLag=(1579) totaldeaths_missionmonLag=(0) contig_land=(0) numMS_deployed=(30) total_fullmiss_change1moLag=(-704) deployment_dur=(36) deployment_durSq=(1296) deployment_durCu=(46656) activedum=(1) shared_colonial_members=(0) colonial_intervener=(0) incompatibility=(1)) vsquish
margins, at (demdum6_potencontrib=(0) brv_AllLag=(298) total_contrib_change1moNegLag=(13) total_contribLag=(1579) totaldeaths_missionmonLag=(0) contig_land=(0) numMS_deployed=(30) total_fullmiss_change1moLag=(-704) deployment_dur=(36) deployment_durSq=(1296) deployment_durCu=(46656) activedum=(1) shared_colonial_members=(0) colonial_intervener=(0) incompatibility=(1)) vsquish
**1995.07: democracy reduces withdrawal by ~21.5
margins, at (demdum6_potencontrib=(1) brv_AllLag=(253) total_contrib_change1moNegLag=(337) total_contribLag=(1242) totaldeaths_missionmonLag=(0) contig_land=(0) numMS_deployed=(30) total_fullmiss_change1moLag=(2888) deployment_dur=(37) deployment_durSq=(1369) deployment_durCu=(50653) activedum=(1) shared_colonial_members=(0) colonial_intervener=(0) incompatibility=(1)) vsquish
margins, at (demdum6_potencontrib=(0) brv_AllLag=(253) total_contrib_change1moNegLag=(337) total_contribLag=(1242) totaldeaths_missionmonLag=(0) contig_land=(0) numMS_deployed=(30) total_fullmiss_change1moLag=(2888) deployment_dur=(37) deployment_durSq=(1369) deployment_durCu=(50653) activedum=(1) shared_colonial_members=(0) colonial_intervener=(0) incompatibility=(1)) vsquish


*Robustness Checks
*Categorical DV (Any sized withdrawal)
*M2: 
logit total_contrib_change1moNegDum i.demdum6_potencontrib##c.brv_AllLag total_contrib_change1moNegLagDum total_contribLag totaldeaths_missionmonLag contig_land numMS_deployed total_fullmiss_change1moLag deployment_dur* activedum shared_colonial_members colonial_intervener incompatibility  if deployed == 1, robust 

*Categorical DV (Any withdrawal >= 25)
*M2: 
logit total_contrib_change1moNegD25 i.demdum6_potencontrib##c.brv_AllLag total_contrib_change1moNegLagD25 total_contribLag totaldeaths_missionmonLag contig_land numMS_deployed total_fullmiss_change1moLag deployment_dur* activedum shared_colonial_members colonial_intervener incompatibility  if deployed == 1, robust 

*Categorical DV (Any withdrawal >= 50)
*M2: This works
logit total_contrib_change1moNegD50 i.demdum6_potencontrib##c.brv_AllLag total_contrib_change1moNegLagD50 total_contribLag totaldeaths_missionmonLag contig_land numMS_deployed total_fullmiss_change1moLag deployment_dur* activedum shared_colonial_members colonial_intervener incompatibility  if deployed == 1, robust 

*Inclusive measure of democracy (Polity IV +5 and above)
nbreg total_contrib_change1moNeg i.demdum5_potencontrib##c.brv_AllLag total_contrib_change1moNegLag total_contribLag totaldeaths_missionmonLag contig_land numMS_deployed total_fullmiss_change1moLag deployment_dur* activedum shared_colonial_members colonial_intervener incompatibility  if deployed == 1, robust 

*Exclusive measure of democracy (Polity IV +7 and above)
nbreg total_contrib_change1moNeg i.demdum7_potencontrib##c.brv_AllLag total_contrib_change1moNegLag total_contribLag totaldeaths_missionmonLag contig_land numMS_deployed total_fullmiss_change1moLag deployment_dur* activedum shared_colonial_members colonial_intervener incompatibility  if deployed == 1, robust 

*Replicating Model 3 with Active Conflict control included.
nbreg total_contrib_change1moNeg i.demdum6_potencontrib##c.brv_AllLag total_contrib_change1moNegLag total_contribLag totaldeaths_missionmonLag contig_land numMS_deployed total_fullmiss_change1moLag deployment_dur* activedum shared_colonial_members colonial_intervener incompatibility if deployed == 1 & active_24months==1, robust 


*Models from the Empirical Results Appendix
*Table A1, Model 1: 3-Month Lag
nbreg total_contrib_change3moNeg i.demdum6_potencontrib##c.brv_AllLag total_contrib_change3moNegLag total_contribLag totaldeaths_missionmonLag contig_land numMS_deployed total_fullmiss_change1moLag deployment_dur* activedum shared_colonial_members colonial_intervener incompatibility  if deployed == 1, robust 

*Table A2, Model 1: 25 Withdrawal Threshold
logit total_contrib_change1moNegD25 i.demdum6_potencontrib##c.brv_AllLag total_contrib_change1moNegLagD25 total_contribLag totaldeaths_missionmonLag contig_land numMS_deployed total_fullmiss_change1moLag deployment_dur* activedum shared_colonial_members colonial_intervener incompatibility  if deployed == 1, robust

*Table A2, Model 2: Withdrawal Proportions
glm propDV i.demdum6_potencontrib##c.brv_AllLag propDVLag totaldeaths_missionmonLag contig_land numMS_deployed total_fullmiss_change1moLag deployment_dur* activedum shared_colonial_members colonial_intervener incompatibility  if deployed == 1, robust family(nbinomial 100) link(logit)

*Table A2, Model 3: 5% Proportional Threshold
logit propDV_5threshold i.demdum6_potencontrib##c.brv_AllLag propDV_5thresholdLag total_contribLag totaldeaths_missionmonLag contig_land numMS_deployed total_fullmiss_change1moLag deployment_dur* activedum shared_colonial_members colonial_intervener incompatibility  if deployed == 1, robust

*Table A3, Model 1: Violence Trends (1-month half-life)
nbreg total_contrib_change1moNeg i.demdum6_potencontrib##c.brv_All_decay1HLLag total_contrib_change1moNegLag total_contribLag totaldeaths_missionmonLag contig_land numMS_deployed total_fullmiss_change1moLag deployment_dur* activedum shared_colonial_members colonial_intervener incompatibility  if deployed == 1, robust

*Table A4, Model 1: Monthly Dummies
nbreg total_contrib_change1moNeg i.demdum6_potencontrib##c.brv_AllLag total_contrib_change1moNegLag total_contribLag totaldeaths_missionmonLag contig_land numMS_deployed total_fullmiss_change1moLag deployment_dur* activedum shared_colonial_members colonial_intervener incompatibility Jan Feb Mar Apr May Jun Jul Aug Sep Oct Nov Dec if deployed == 1, robust

*Table A4, Model 2: State Deployment Duration
nbreg total_contrib_change1moNeg i.demdum6_potencontrib##c.brv_AllLag total_contrib_change1moNegLag total_contribLag totaldeaths_missionmonLag contig_land numMS_deployed total_fullmiss_change1moLag UNpoten_contrib_timecounter activedum shared_colonial_members colonial_intervener incompatibility  if deployed == 1, robust 

*Table A4, Model 3: Biannual Rotations
nbreg total_contrib_change1moNeg i.demdum6_potencontrib##c.brv_AllLag total_contrib_change1moNegLag total_contribLag totaldeaths_missionmonLag contig_land numMS_deployed total_fullmiss_change1moLag deployment_dur* sixmonth_deploymentDum activedum shared_colonial_members colonial_intervener incompatibility  if deployed == 1, robust 

*Table A4, Model 4: Country Dummies
nbreg total_contrib_change1moNeg i.demdum6_potencontrib##c.brv_AllLag total_contrib_change1moNegLag total_contribLag totaldeaths_missionmonLag contig_land numMS_deployed total_fullmiss_change1moLag deployment_dur* activedum shared_colonial_members colonial_intervener incompatibility TCC* if deployed == 1, robust iterate(1000)






